@@ -5,14 +5,14 @@
 #define _GNU_SOURCE
 
 #define PROG           "debram"
-#define VERSION        "0.4.1"
+#define VERSION        "0.6.1"
 
 #define DATA_FILE_BASENAME \
   "debram.txt"
 #ifdef  DEBRAM_LOCAL
-  #define DATA_FILE                      DATA_FILE_BASENAME
+  #define DATA_FILE                        DATA_FILE_BASENAME
 #else
-  #define DATA_FILE "/usr/lib/" PROG "/" DATA_FILE_BASENAME
+  #define DATA_FILE "/usr/share/" PROG "/" DATA_FILE_BASENAME
 #endif
 #define DATA_FILE_GZ   DATA_FILE ".gz"
 
